@@ -13,12 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
+"""Tests for `control_variates.py`."""
+
 from absl.testing import absltest
 from absl.testing import parameterized
 import chex
 import jax
 import jax.numpy as jnp
 import numpy as np
+
 from optax._src import control_variates
 from optax._src import stochastic_gradient_estimators as sge
 from optax._src import utils
@@ -29,13 +32,15 @@ np.random.seed(42)
 
 
 def _assert_equal(actual, expected, rtol=1e-2, atol=1e-2):
+  """Asserts that arrays are equal."""
   # Note: assert_allclose does not check shapes
-  assert actual.shape == expected.shape
+  chex.assert_equal_shape((actual, expected))
 
   # Scalar.
   if not actual.shape:
-    return np.testing.assert_allclose(
+    np.testing.assert_allclose(
         np.asarray(actual), np.asarray(expected), rtol, atol)
+    return
 
   # We get around the bug https://github.com/numpy/numpy/issues/13801
   zero_indices = np.argwhere(expected == 0)
@@ -276,6 +281,7 @@ class MovingAverageBaselineTest(chex.TestCase):
 
 
 class DeltaMethodAnalyticalExpectedGrads(chex.TestCase):
+  """Tests for grads approximations."""
 
   @chex.all_variants
   @parameterized.named_parameters(
@@ -454,6 +460,7 @@ class DeltaMethodAnalyticalExpectedGrads(chex.TestCase):
 
 
 class ConsistencyWithStandardEstimators(chex.TestCase):
+  """Tests for consistency between estimators."""
 
   @chex.all_variants
   @parameterized.named_parameters(
